@@ -37,13 +37,12 @@ func fakeServer() (*ArgoCDServer, func()) {
 	redis, closer := test.NewInMemoryRedis()
 
 	argoCDOpts := ArgoCDServerOpts{
-		Namespace:       test.FakeArgoCDNamespace,
-		KubeClientset:   kubeclientset,
-		AppClientset:    appClientSet,
-		Insecure:        true,
-		DisableAuth:     true,
-		StaticAssetsDir: "../test/testdata/static",
-		XFrameOptions:   "sameorigin",
+		Namespace:     test.FakeArgoCDNamespace,
+		KubeClientset: kubeclientset,
+		AppClientset:  appClientSet,
+		Insecure:      true,
+		DisableAuth:   true,
+		XFrameOptions: "sameorigin",
 		Cache: servercache.NewCache(
 			appstatecache.NewCache(
 				cacheutil.NewCache(cacheutil.NewInMemoryCache(1*time.Hour)),
@@ -225,7 +224,7 @@ func TestInitializingExistingDefaultProject(t *testing.T) {
 	secret := test.NewFakeSecret()
 	kubeclientset := fake.NewSimpleClientset(cm, secret)
 	defaultProj := &v1alpha1.AppProject{
-		ObjectMeta: metav1.ObjectMeta{Name: common.DefaultAppProjectName, Namespace: test.FakeArgoCDNamespace},
+		ObjectMeta: metav1.ObjectMeta{Name: v1alpha1.DefaultAppProjectName, Namespace: test.FakeArgoCDNamespace},
 		Spec:       v1alpha1.AppProjectSpec{},
 	}
 	appClientSet := apps.NewSimpleClientset(defaultProj)
@@ -239,10 +238,10 @@ func TestInitializingExistingDefaultProject(t *testing.T) {
 	argocd := NewServer(context.Background(), argoCDOpts)
 	assert.NotNil(t, argocd)
 
-	proj, err := appClientSet.ArgoprojV1alpha1().AppProjects(test.FakeArgoCDNamespace).Get(context.Background(), common.DefaultAppProjectName, metav1.GetOptions{})
+	proj, err := appClientSet.ArgoprojV1alpha1().AppProjects(test.FakeArgoCDNamespace).Get(context.Background(), v1alpha1.DefaultAppProjectName, metav1.GetOptions{})
 	assert.Nil(t, err)
 	assert.NotNil(t, proj)
-	assert.Equal(t, proj.Name, common.DefaultAppProjectName)
+	assert.Equal(t, proj.Name, v1alpha1.DefaultAppProjectName)
 }
 
 func TestInitializingNotExistingDefaultProject(t *testing.T) {
@@ -260,10 +259,10 @@ func TestInitializingNotExistingDefaultProject(t *testing.T) {
 	argocd := NewServer(context.Background(), argoCDOpts)
 	assert.NotNil(t, argocd)
 
-	proj, err := appClientSet.ArgoprojV1alpha1().AppProjects(test.FakeArgoCDNamespace).Get(context.Background(), common.DefaultAppProjectName, metav1.GetOptions{})
+	proj, err := appClientSet.ArgoprojV1alpha1().AppProjects(test.FakeArgoCDNamespace).Get(context.Background(), v1alpha1.DefaultAppProjectName, metav1.GetOptions{})
 	assert.Nil(t, err)
 	assert.NotNil(t, proj)
-	assert.Equal(t, proj.Name, common.DefaultAppProjectName)
+	assert.Equal(t, proj.Name, v1alpha1.DefaultAppProjectName)
 }
 
 func TestEnforceProjectGroups(t *testing.T) {
@@ -501,7 +500,7 @@ func TestInitializeDefaultProject_ProjectDoesNotExist(t *testing.T) {
 	}
 
 	proj, err := argoCDOpts.AppClientset.ArgoprojV1alpha1().
-		AppProjects(test.FakeArgoCDNamespace).Get(context.Background(), common.DefaultAppProjectName, metav1.GetOptions{})
+		AppProjects(test.FakeArgoCDNamespace).Get(context.Background(), v1alpha1.DefaultAppProjectName, metav1.GetOptions{})
 
 	if !assert.NoError(t, err) {
 		return
@@ -517,7 +516,7 @@ func TestInitializeDefaultProject_ProjectDoesNotExist(t *testing.T) {
 func TestInitializeDefaultProject_ProjectAlreadyInitialized(t *testing.T) {
 	existingDefaultProject := v1alpha1.AppProject{
 		ObjectMeta: metav1.ObjectMeta{
-			Name:      common.DefaultAppProjectName,
+			Name:      v1alpha1.DefaultAppProjectName,
 			Namespace: test.FakeArgoCDNamespace,
 		},
 		Spec: v1alpha1.AppProjectSpec{
@@ -538,7 +537,7 @@ func TestInitializeDefaultProject_ProjectAlreadyInitialized(t *testing.T) {
 	}
 
 	proj, err := argoCDOpts.AppClientset.ArgoprojV1alpha1().
-		AppProjects(test.FakeArgoCDNamespace).Get(context.Background(), common.DefaultAppProjectName, metav1.GetOptions{})
+		AppProjects(test.FakeArgoCDNamespace).Get(context.Background(), v1alpha1.DefaultAppProjectName, metav1.GetOptions{})
 
 	if !assert.NoError(t, err) {
 		return
@@ -546,24 +545,3 @@ func TestInitializeDefaultProject_ProjectAlreadyInitialized(t *testing.T) {
 
 	assert.Equal(t, proj.Spec, existingDefaultProject.Spec)
 }
-
-func TestFileExists(t *testing.T) {
-	t.Run("File exists and path is within dir", func(t *testing.T) {
-		exists := fileExists(".", "server.go")
-		assert.True(t, exists)
-		exists = fileExists(".", "account/account.go")
-		assert.True(t, exists)
-	})
-	t.Run("File does not exist", func(t *testing.T) {
-		exists := fileExists(".", "notexist.go")
-		assert.False(t, exists)
-	})
-	t.Run("Dir does not exist", func(t *testing.T) {
-		exists := fileExists("/notexisting", "server.go")
-		assert.False(t, exists)
-	})
-	t.Run("File outside of dir", func(t *testing.T) {
-		exists := fileExists(".", "../reposerver/server.go")
-		assert.False(t, exists)
-	})
-}
